.. _commands:

Commands
========

.. Use a hidden table of contents to ensure that documentation is read.

.. include:: toc.rst

Charmcraft has several commands used for managing the building, uploading and releasing
of a charm.

:ref:`ref_commands_init`
    Initialise a charm operator package tree and files.

.. _reference-lifecycle-commands:

Lifecycle commands
------------------

.. include:: lifecycle-commands.rst


.. _reference-store-commands:

Store commands
--------------

Store commands fall into several categories, depending on the particular command.


.. _reference-account-commands:

Account commands
~~~~~~~~~~~~~~~~

.. include:: store (account)-commands.rst


.. _reference-charm-commands:

Charm commands
~~~~~~~~~~~~~~

.. include:: store (charm)-commands.rst


.. _reference-library-commands:

Library commands
~~~~~~~~~~~~~~~~

.. include:: store (libraries)-commands.rst


.. _reference-extension-commands:

Extension commands
------------------

.. include:: extensions-commands.rst


.. _reference-other-commands:

Other commands
--------------

.. include:: other-commands.rst
